@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,13 +42,15 @@ Chile_Default_Firefox_esr
    <ja>スペイン語（チリ）版 Firefox ESR</ja>
    <kk>Spanish (Chile) localisation of Firefox ESR</kk>
    <ko>Spanish (Chile) localisation of Firefox ESR</ko>
+   <ku>Spanish (Chile) localisation of Firefox ESR</ku>
    <lt>Spanish (Chile) localisation of Firefox ESR</lt>
    <mk>Spanish (Chile) localisation of Firefox ESR</mk>
    <mr>Spanish (Chile) localisation of Firefox ESR</mr>
    <nb_NO>Spanish (Chile) localisation of Firefox ESR</nb_NO>
    <nb>Spansk (chilensk) lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Spanish (Chile) localisation of Firefox ESR</nl_BE>
-   <nl>Spanish (Chile) localisation of Firefox ESR</nl>
+   <nl>Spaanse (Chili) lokalisatie van Firefox ESR</nl>
+   <or>Spanish (Chile) localisation of Firefox ESR</or>
    <pl>Spanish (Chile) localisation of Firefox ESR</pl>
    <pt_BR>Espanhol (Chile) Localização para o Firefox ESR</pt_BR>
    <pt>Castelhano (Chile) Localização para Firefox ESR</pt>
@@ -56,6 +58,7 @@ Chile_Default_Firefox_esr
    <ru>Spanish (Chile) localisation of Firefox ESR</ru>
    <sk>Spanish (Chile) localisation of Firefox ESR</sk>
    <sl>Španske (Čile) krajevne nastavitve za Firefox-ESR</sl>
+   <so>Spanish (Chile) localisation of Firefox ESR</so>
    <sq>Përkthimi i Firefox-it ESR në spanjisht (Kili)</sq>
    <sr>Spanish (Chile) localisation of Firefox ESR</sr>
    <sv>Spansk (Chile) lokalisering av Firefox ESR</sv>
