@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="UTF-8"?>
+<?xml version="1.0"?>
 <app>
 
 <category>
@@ -78,11 +78,12 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-
+echo "deb http://deb.debian.org/debian trixie-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
+apt-get update
 </preinstall>
 
 <install_package_names>
--t bookworm-backports libreoffice-calc
+-t trixie-backports libreoffice-calc
 libreoffice-draw
 libreoffice-impress
 libreoffice-math
@@ -93,7 +94,8 @@ libreoffice-gtk3
 </install_package_names>
 
 <postinstall>
-
+rm /etc/apt/sources.list.d/pitemp.list
+apt-get update
 </postinstall>
 
 <uninstall_package_names>
