@@ -1,4 +1,4 @@
-<?xml version="1.0" encoding="UTF-8"?>
+<?xml version="1.0"?>
 <app>
 
 <category>
@@ -78,12 +78,12 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "deb http://deb.debian.org/debian bullseye-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
+echo "deb http://deb.debian.org/debian trixie-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
 apt-get update
 </preinstall>
 
 <install_package_names>
--t bullseye-backports libreoffice-calc
+-t trixie-backports libreoffice-calc
 libreoffice-draw
 libreoffice-impress
 libreoffice-math
