@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Turkish_Thunderbird
    <ja>Thunderbird のトルコ語版</ja>
    <kk>Turkish localisation of Thunderbird</kk>
    <ko>Turkish localisation of Thunderbird</ko>
+   <ku>Turkish localisation of Thunderbird</ku>
    <lt>Turkish localisation of Thunderbird</lt>
    <mk>Turkish localisation of Thunderbird</mk>
    <mr>Turkish localisation of Thunderbird</mr>
@@ -49,6 +50,7 @@ Turkish_Thunderbird
    <nb>Tyrkisk lokaltilpassing av Thunderbird</nb>
    <nl_BE>Turkish localisation of Thunderbird</nl_BE>
    <nl>Turkse lokalisatie van Thunderbird</nl>
+   <or>Turkish localisation of Thunderbird</or>
    <pl>Turecka lokalizacja Thunderbirda</pl>
    <pt_BR>Turco Localização para o Thunderbird</pt_BR>
    <pt>Turco Localização para Thunderbird</pt>
@@ -56,6 +58,7 @@ Turkish_Thunderbird
    <ru>Turkish localisation of Thunderbird</ru>
    <sk>Turkish localisation of Thunderbird</sk>
    <sl>Turške krajevne nastavitve za Thunderbird</sl>
+   <so>Turkish localisation of Thunderbird</so>
    <sq>Përkthimi i Thunderbird-it në turqisht</sq>
    <sr>Turkish localisation of Thunderbird</sr>
    <sv>Turkisk lokalisering av Thunderbird</sv>
