@@ -67,9 +67,17 @@ LibreWolf
 <screenshot></screenshot>
 
 <preinstall>
-wget https://deb.librewolf.net/keyring.gpg -O /etc/apt/trusted.gpg.d/librewolf.gpg
-echo "deb [arch=amd64] http://deb.librewolf.net bookworm main">/etc/apt/sources.list.d/librewolf.list
+rm -f /etc/apt/sources.list.d/librewolf.sources
+rm -f /etc/apt/keyrings/librewolf.gpg
+rm -f /etc/apt/preferences.d/librewolf.pref
+rm -f /etc/apt/sources.list.d/librewolf.list
+rm -f /etc/apt/trusted.gpg.d/librewolf.gpg
 apt-get update
+apt-get install extrepo -y
+extrepo enable librewolf
+env LC_CTYPE=C.UTF-8 sed -i '/^URIs/I{/URIs/b;s/^uris/URIs/I} ' /etc/apt/sources.list.d/*.sources
+apt-get update
+
 </preinstall>
 
 <install_package_names>
@@ -78,7 +86,27 @@ librewolf
 
 
 <postinstall>
+if [ -d /usr/share/xfce4/helpers ]; then
+if ! [ -f /usr/share/xfce4/helpers/librewolf.desktop ]; then
 
+cat &lt;&lt;'EOF' &gt; /usr/share/xfce4/helpers/librewolf.desktop
+[Desktop Entry]
+Version=1.0
+Encoding=UTF-8
+Icon=librewolf
+Name=LibreWolf
+NoDisplay=true
+StartupNotify=false
+Terminal=false
+Type=X-XFCE-Helper
+X-XFCE-Binaries=librewolf;
+X-XFCE-Category=WebBrowser
+X-XFCE-Commands=%B;
+X-XFCE-CommandsWithParameter=%B "%s";
+
+EOF
+fi
+fi
 </postinstall>
 
 <uninstall_package_names>
@@ -86,6 +114,10 @@ librewolf
 </uninstall_package_names>
 
 <postuninstall>
-
+if [ -f /usr/share/xfce4/helpers/librewolf.desktop ]; then
+rm /usr/share/xfce4/helpers/librewolf.desktop
+fi
+extrepo disable librewolf
+apt-get update
 </postuninstall>
 </app>
