@@ -6,7 +6,7 @@ Desktop Environments
 </category>
 
 <name>
-LXDE
+LXDE with Consolekit
 </name>
 
 <description>
