@@ -1,4 +1,4 @@
-<?xml version="1.0"?>
+<?xml version="1.0" encoding="UTF-8"?>
 <app>
 
 <category>
@@ -42,6 +42,7 @@ Pulseaudio
    <ja>高機能なサウンドサーバーシステム</ja>
    <kk>Advanced sound server system</kk>
    <ko>Advanced sound server system</ko>
+   <ku>Advanced sound server system</ku>
    <lt>Advanced sound server system</lt>
    <mk>Advanced sound server system</mk>
    <mr>Advanced sound server system</mr>
@@ -49,6 +50,7 @@ Pulseaudio
    <nb>Avansert lydtjener-system</nb>
    <nl_BE>Advanced sound server system</nl_BE>
    <nl>Advanced sound server system</nl>
+   <or>Advanced sound server system</or>
    <pl>Advanced sound server system</pl>
    <pt_BR>Sistema de servidor de som avançado</pt_BR>
    <pt>Sistema de servidor de som avançado</pt>
@@ -56,6 +58,7 @@ Pulseaudio
    <ru>Advanced sound server system</ru>
    <sk>Advanced sound server system</sk>
    <sl>Napredni sistem zvočnega strežnika</sl>
+   <so>Advanced sound server system</so>
    <sq>Sistem i thelluar shërbyesi tingujsh</sq>
    <sr>Advanced sound server system</sr>
    <sv>Avancerat ljudserver-system</sv>
