@@ -6,7 +6,7 @@ Desktop Environments
 </category>
 
 <name>
-Xfce4-lite without elogind
+Xfce4-lite with Consolekit
 </name>
 
 <description>
@@ -83,7 +83,10 @@ all
 
 <install_package_names>
 xfce4
+consolekit
+libpam-ck-connector
 thunar-volman
+
 </install_package_names>
 
 
@@ -94,6 +97,8 @@ thunar-volman
 
 <uninstall_package_names>
 xfce4
+consolekit
+libpam-ck-connector
 thunar-volman
 </uninstall_package_names>
 </app>
